@@ -50,7 +50,7 @@ class Resource():
         for root, dirs, files in os.walk(resource_dir_path, topdown=False):
             for n in self.resource_dir_names:
                 # imgs/xx_XX/xx.xx, for locale resources.
-                if (root.endswith(n) or root.split('/')[-2] == n) \
+                if (root.endswith(n) or root.split(os.sep)[-2] == n) \
                         and len(dirs) < 1:
                     for name in files:
                         resource_paths.append(os.path.join(root, name))
