@@ -4,6 +4,7 @@
 # ' 汉语拼音',
 
 cn_ps_c = [
+    # 1.1
     [
         [
             '爸', '妈', '我',
@@ -17,7 +18,8 @@ cn_ps_c = [
             '飞', '机', '有', '儿', '河', '入', '校',
             '山', '田', '左', '片', '右', '半', '云', '她',
             '老', '师', '文', '朵', '鹅', '条', '雨', '天', '桥',
-        ], [
+        ],
+        [
             '一', '去', '二', '三', '里', '四', '五', '六', '七', '八', '九', '十',
             '耳目', '羊鸟', '兔', '日', '月', '火', '木', '禾', '竹',
             '沙', '发', '报', '纸', '台', '灯', '电', '视', '晚', '上', '送', '果',
@@ -36,7 +38,8 @@ cn_ps_c = [
             '前', '后', '常', '跟', '着', '黑', '狗', '它', '朋', '友',
             '比', '尾', '巴', '短', '把', '猴', '松', '鼠', '扁', '最', '公', '鸭',
 
-        ], [
+        ],
+        [
             '黄', '猫', '杏', '桃', '苹', '红', '边', '多', '少', '群', '颗', '堆',
             '商', '场', '包', '奶', '牙', '毛', '巾', '笔', '尺', '作', '业', '本',
             '东', '西',
@@ -57,7 +60,9 @@ cn_ps_c = [
             '孩', '让', '起', '玩', '往', '觉', '烧', '知', '道', '化',
             '砍', '造', '满', '舍', '结', '年', '直', '动', '束', '丽',
         ],
-    ], [
+    ],
+    # 1.2
+    [
         [
             '万', '复', '苏', '柳', '歌', '舞', '冰', '泉', '丁', '百', '齐', '争',
             '鸣',
@@ -67,7 +72,8 @@ cn_ps_c = [
             '亲',
             '诗', '首', '眠', '处', '闻', '村', '居', '醉', '烟', '童', '散', '忙',
             '访', '挤', '邮', '局', '轿', '钱',
-        ], [
+        ],
+        [
             '貌', '父', '母', '教', '认', '错', '事', '改', '愿', '碗', '筷', '扫',
             '夸',
             '全', '奇', '妙', '却', '精', '赛', '关', '掉', '完', '换', '员', '写',
@@ -79,7 +85,8 @@ cn_ps_c = [
             '帘', '女', '背', '装', '气', '另', '顾', '病', '太', '累', '医', '悄',
             '离', '户',
             '元', '旦', '值', '篇', '遍',
-        ], [
+        ],
+        [
             '霜', '朝', '霞', '夕', '蝶', '蜂', '碧', '紫', '千', '李', '杨', '秀',
             '蛋', '取', '凉', '定', '棒', '连', '轻', '仿', '佛', '抬', '投', '向',
             '聪', '活', '泼', '忽', '然', '眨', '如', '总', '以', '主', '意',
@@ -88,7 +95,8 @@ cn_ps_c = [
             '失', '级', '同', '观', '围', '工', '专', '准', '备', '队', '才', '请',
             '双', '各',
             '代', '舌', '页', '弓', '秒', '炒',
-        ], [
+        ],
+        [
             '蜓', '展', '蝴', '蚯', '蚓', '蚂', '蚁', '运', '蝌', '蚪', '蜘', '蛛',
             '网',
             '所', '牧', '捕', '蝉', '闭', '立', '池', '惜', '阴', '晴', '柔', '露',
@@ -98,7 +106,8 @@ cn_ps_c = [
             '坡', '割', '闷', '伸', '喊', '潮', '湿', '虫', '消', '搬', '阵', '哗',
             '壁', '虎', '借', '蚊', '蛇', '逃', '难', '姐', '新',
             '抄', '拾', '摔', '拨', '拦', '摸',
-        ], [
+        ],
+        [
             '量', '相', '遇', '及', '怕', '攻', '互', '尊', '重', '令', '纯',
             '文：',
             '挂', '街', '熟', '伙', '伴', '尝', '甜', '温', '冻', '脸', '该', '因',
@@ -109,7 +118,8 @@ cn_ps_c = [
             '称', '象', '官', '腿', '柱', '议', '杆', '秤', '倒', '艘', '沉', '止',
             '微',
             '瘦', '暗', '丑', '闲', '旧',
-        ], [
+        ],
+        [
             '鸥', '滩', '军', '舰', '帆', '秧', '稻', '塘', '溪', '竿', '铜', '号',
             '领',
             '忘', '挖', '井', '席', '导', '革', '命', '战', '士', '解', '刻', '念',
@@ -120,7 +130,8 @@ cn_ps_c = [
             '敬', '度',
 
             '甲', '申', '句', '兄',
-        ], [
+        ],
+        [
             '骄', '傲', '淡', '诚', '实', '赢', '赞', '招',
             '翻', '浇', '施', '肥', '饿', '候', '挑', '担',
             '狮', '整', '练', '习', '滚', '扑', '咬', '苦', '懒', '洋', '吞', '将',
@@ -130,7 +141,8 @@ cn_ps_c = [
             '盆', '位', '选', '并', '宣', '分', '芽', '规', '盛', '丝', '表', '煮',
 
             '饮', '饺', '猪', '狼',
-        ], [
+        ],
+        [
             '眉', '辨', '斗', '湖', '即', '雁', '归', '转', '寒',
             '姑', '娘', '蚜', '盼', '治', '啄', '斑',
             '俩', '摘', '伯', '而', '且', '踢', '引',
@@ -139,29 +151,30 @@ cn_ps_c = [
             '梦', '名',
             '灰', '迎', '阿', '姨', '追', '顶', '披', '鼓',
 
-            '埋', '闯', '掰', '跌', ]
-    ], [
+            '埋', '闯', '掰', '跌',
+        ]
+    ],
+    # 2.1
+    [
         [
-            # '共个字)',
-            # '字表',
-            # '三册：',
-            # '字一：',
             '层', '尽', '染', '叠', '翠', '爽', '壮', '谷', '登', '华',
             '图', '梨', '笼', '浪', '梁', '燃', '勤', '劳',
             '区', '尤', '其', '仙', '盘', '峰', '胳', '膊', '巨', '当', '脖', '著',
             '形', '状',
             '旅', '蒲', '降', '娃', '纷', '苍', '洼', '啪', '炸', '蹦', '察', '识',
             '刘', '菊', '残', '君', '橙', '橘', '径', '斜', '枫', '于',
-            # '文园地一：',
-            '支', '龙', '求', '凡', '利', ], [
-            # '字：',
+            '支', '龙', '求', '凡', '利',
+        ],
+        [
             '弹', '钢', '琴', '胡', '戏', '喂', '鸽', '养', '航', '模',
             '株', '踮', '院', '除', '疲', '倦', '牵', '困',
             '委', '补', '室', '宁', '愣', '切', '集', '掌',
             '零', '闹', '哈', '欠', '迟', '叹', '决', '悔',
             '算', '冒', '览', '馆', '紧', '怦', '握', '容', '普', '奋', '灿', '烂',
             # '文园地二：',
-            '纪', '纺', '织', '优', '胜', '湾', '粒', ], [
+            '纪', '纺', '织', '优', '胜', '湾', '粒',
+        ],
+        [
             # '字：',
             '州', '川', '涌', '岛', '隔', '峡', '与', '陆', '民', '族',
             '献', '帜', '洁', '奏', '曲', '亿',
@@ -170,7 +183,9 @@ cn_ps_c = [
             '扬',
             '店', '橱', '指', '接', '讲', '铺', '毯', '银', '仗',
             # '文园地三：',
-            '危', '险', '买', '卖', '反', '杂', '简', '单', ], [
+            '危', '险', '买', '卖', '反', '杂', '简', '单',
+        ],
+        [
             # '字：',
             '益', '彰', '豹', '障', '泰', '徒', '功', '渠',
             '际', '信',
@@ -179,7 +194,9 @@ cn_ps_c = [
             '续', '吸', '极', '夫', '汗', '驶', '示', '筝', '踪', '伤', '责',
             '葡', '萄', '狐', '狸', '串', '迫', '待', '硬',
             # '文园地四：',
-                '泡', '袍', '鞭', '炮', ], [
+            '泡', '袍', '鞭', '炮',
+        ],
+        [
             # '字：',
             '谋', '柴', '焰', '易', '折', '搓', '绳', '斤', '独',
             '猬', '板', '凳', '糙', '但', '傍', '椅', '瞧', '留',
@@ -187,7 +204,9 @@ cn_ps_c = [
             '扎', '抓', '莓', '幸', '福', '吵', '受',
             '轮', '期', '第', '任', '惯', '式', '眯', '郑',
             # '文园地五：',
-            '钉', '裙', '裤', '袄', '疼', '痛', '疯', ], [
+            '钉', '裙', '裤', '袄', '疼', '痛', '疯',
+        ],
+        [
             # '字：',
             '漠', '炭', '贫', '富', '饥', '索', '奉', '永',
             '亚', '呆', '始', '猜', '拴', '逗',
@@ -195,7 +214,9 @@ cn_ps_c = [
             '昨', '纱', '羡', '慕', '粉', '料', '套', '份', '妹', '贵', '寄', '费',
             '何', '赠', '汪', '舟', '欲', '踏', '潭',
             # '文园地六：',
-            '贡', '肯', '扇', '确', '愁', ], [
+            '贡', '肯', '扇', '确', '愁',
+        ],
+        [
             # '字：',
             '牢', '孔', '雀', '锦', '鹰', '丛', '鹂', '灵', '嬉',
             '喳', '蓬', '跃', '棱', '巢', '崭', '牌',
@@ -204,31 +225,32 @@ cn_ps_c = [
             '喃', '味', '浓', '腾', '猎', '黎',
             # '字：',
             '卫', '填', '嫦', '娥', '宇', '宙', '载', '箭',
-                '雹', '暴', '躁', '灌', '溉', '器', '淹', '稼', '毁', '灾',
-                '哩', '圈', '纹', '碰', '返',
-                '必', '须', '绑', '通', '杯', '塑', '咳', '嗽', '钩', '件', '喷',
+            '雹', '暴', '躁', '灌', '溉', '器', '淹', '稼', '毁', '灾',
+            '哩', '圈', '纹', '碰', '返',
+            '必', '须', '绑', '通', '杯', '塑', '咳', '嗽', '钩', '件', '喷',
                  '设', '浴',
-                '珍', '孙', '悉', '绝', '肉', '史', '核', '缺', '乏', '稀',
-                '技', '袁', '隆', '介', '绍', '培', '育', '产', '棚', '控', '制',
-                '泥', '拙',
+            '珍', '孙', '悉', '绝', '肉', '史', '核', '缺', '乏', '稀',
+            '技', '袁', '隆', '介', '绍', '培', '育', '产', '棚', '控', '制',
+            '泥', '拙',
         ],
-    ], [
+    ],
+    # 2.2
+    [
         [
-            # '共个字）',
-            # '字表',
-            # '四册',
-            # '字学词学句(一)：',
-
             '泰', '州', '贵', '兵', '龙', '佛', '历', '史', '悠', '久', '迎',
             '份', '泳', '游', '冻', '裂', '较', '杆', '抖', '躲', '蛇', '丛', '钉',
             '订',
             '胡', '吴', '弓', '章', '吕', '横', '官', '良', '姓', '赵', '钱', '孙',
-            '谷', '至', '懂', '撒', '争', '管', '勤', '丰', ], [
+            '谷', '至', '懂', '撒', '争', '管', '勤', '丰',
+        ],
+        [
             # '文：',
             '所', '牧', '骑', '振', '欲', '捕', '鸣', '闭',
             '惜', '照', '柔',
             '碧', '垂', '丝', '裁', '似', '剪',
-            '烟', '趁', '纸', ], [
+            '烟', '趁', '纸',
+        ],
+        [
             # '图学文：',
             '蝌', '蚪', '群', '灰', '腿', '姨', '宽', '嘴', '龟', '摆', '追', '肚',
             '鼓',
@@ -241,11 +263,12 @@ cn_ps_c = [
             '亏',
             '雷', '锋', '叔', '寻', '迷', '顺', '背', '娘', '踏', '瓣', '珠', '滴',
             '终', '于',
-                '幕', '临', '街', '闪', '夺', '勾', '喷', '府', '紫', '禁', '束',
-                '潭', '环', '绕', '岛', '称', '隐', '约映', '建', '筑', '仙', '境',
-                '汗', '透', '校', '病', '摸', '脸',
-                '夸', '佳', '炸', '弹', '划', '救', '血', '愉', '串', '恳', '思',
-        ], [
+            '幕', '临', '街', '闪', '夺', '勾', '喷', '府', '紫', '禁', '束',
+            '潭', '环', '绕', '岛', '称', '隐', '约映', '建', '筑', '仙', '境',
+            '汗', '透', '校', '病', '摸', '脸',
+            '夸', '佳', '炸', '弹', '划', '救', '血', '愉', '串', '恳', '思',
+        ],
+        [
             # '字学词学句(二)：',
             '臼', '齿', '穴', '骨', '革', '皿', '页', '码', '犬', '爪', '足', '部',
             '形', '义',
@@ -253,119 +276,117 @@ cn_ps_c = [
             '腰', '体',
             '度', '积', '蝴', '蝶', '驶', '渔', '蚊', '舰', '挎', '篮', '取', '趣',
             '棋',
-                '缓', '退', '始', '强弱', '困', '懒', '惰', '费', '荣', '功', '失',
-                '败虚',
-                # '图学文：',
-        ], [
+            '缓', '退', '始', '强弱', '困', '懒', '惰', '费', '荣', '功', '失',
+            '败虚',
+            # '图学文：',
+        ],
+        [
             '区', '神', '尤', '其', '翻', '滚', '指', '巨', '著', '琴', '状', '岩',
             '沉', '压', '乱', '网', '逃', '越', '渐', '虹',
-            '文：', ], [
+            '文：',
+        ],
+        [
             '葡', '萄', '沟', '产', '坡', '密', '搭', '棚', '够', '制', '留', '颜',
             '泼', '因', '敬', '恩', '总', '炮', '祝', '福', '健', '康', '幸', '令',
             '引', '莫', '斯', '派', '谈', '敲', '讶', '导',
-                '播', '担', '被', '锣', '眨', '咬', '钩', '铜', '微', '转',
-                '卫', '丹', '艺', '旗', '擦', '斜', '男', '显',
-                '澈', '卷', '波', '纹', '丢', '幻', '觉', '消', '表', '演', '扔',
-                '盼',
-                '慌', '针', '辨', '忠', '稠', '稀',
-                '曹', '操', '秤', '砍', '割', '线', '量',
-                '求', '剑', '宝', '催', '靠',
-                '狼', '溪', '脏', '怜', '辩', '扑',
-                '卧', '钻', '剩', '欺', '啄', '讨', '厌', '离', ], ], [[
-                    # '共个生字）',
-
-                    # '字表',
-                    # '五册',
-                    # '图学文',
-                    '匆', '蔼', '尊', '戴', '累', '凑', '补', '输', '液', '扰',
-                    '玻', '璃', '吊', '瓶', '默',
-                    '汉', '硬', '朗', '县', '济', '毕', '竟', '灵', '便', '及',
-                    '盐', '换', '净', '眯',
-                    '散', '脯', '蹦', '惹', '仰', '渣', '定', '或', '但', '肯',
-                    # '文',
-                ], [
-                    '诗', '娇', '恰', '菊', '舍', '陶', '偏', '此', '尽',
-                    '陡', '级', '铁', '链', '乎', '颤', '奋', '攀', '并', '鲫',
-                    '念', '辫', '勇', '决',
-                    '欣', '赏', '封', '乳', '浓', '射', '献', '酸', '脆', '参',
-                    '刮', '肥', '鼠', '库',
-                    '盖', '造', '犁', '断', '减', '扩', '栋', '具', '冒', '柴',
-                    '黎', '洪', '何', '括',
-                    '焦', '筋', '疲', '喘', '枯', '亡', '牢', '圈', '破', '叼',
-                    '劝', '修', '堵', '悔', '受',
-                    '招', '副', '善', '性', '特', '骗', '狡', '猾', '使', '劲',
-                    '扫', '凶', '恶', '狠', '拾',
-                    '摄', '格', '媚', '桌', '志', '贴', '鞠', '躬', '按', '侧',
-                    '胶', '辆', '秘', '杂', '社',
-                    '财', '富', '厂', '牌', '式', '赠', '拥', '与', '德', '题',
-                    '票', '存', '号', '忆',
-                    '鹿', '返', '复', '君', '逢', '芙', '蓉', '暮', '贫', '吠',
-                    '防', '哨', '峡', '甲', '威', '武', '插', '滩', '壳', '粪',
-                    '料', '守', '设', '必', '将',
-                    '顿', '庭', '零', '绩', '麦', '奖', '卡', '推', '羞', '通',
-                    '愤', '遇', '任', '研', '惯',
-                    '基', '础', '差', '末', '考', '试', '均', '厕', '努', '授',
-                    '旧', '项', '需', '技', '震',
-                    '乘', '轮', '司', '叹', '铃', '裙', '齐', '聪', '佩', '据',
-                    '示', '感', '乖', '赞', '致',
-                    '棒', '敌', '激', '烈', '陆', '续', '淹', '仍', '吼', '险',
-                    '势', '继', '迅', '速', '秒',
-                    # '共个字)',
-                ],
-    ], [
-                    [
-
-                        # '字表',
-                        # '六册',
-                        # '图学文：',
-                        '筝', '育', '鹰', '端', '稳', '嚷', '橘', '墨', '斑',
-                        '闹', '宇', '宙', '荡', '衬',
-                        '赛', '拨', '警', '惕', '膝', '豪', '套', '倾', '探',
-                        '扎', '索', '搂', '贯', '局',
-                        # '文：',],[
-                    ], [
-                        '昼', '耘', '未', '耕', '织', '桑', '蓬', '稚', '纶',
-                        '莓', '苔',
-                        '嘱', '排', '而', '确', '幅', '却', '哈', '审', '肃',
-                        '晌', '悦', '悉', '诲',
-                        '例', '芝', '卵', '匀', '寸', '呆', '增', '隔', '壁',
-                        '搬', '烛', '慈', '肩', '捧',
-                        '匠', '伟', '砌', '跨', '创', '既', '击', '毁', '坚',
-                        '固', '且', '案', '智', '慧',
-                        '阶', '厅', '礼', '席', '灿', '烂', '党', '描', '敞',
-                        '椅', '议', '内', '宾',
-                        '秆', '绣', '腹', '赤', '衫', '疾', '泛', '泡', '脱',
-                        '锐', '晃', '饲', '希',
-                        '狭', '桂', '刺', '软', '触', '滑', '唇', '汁', '津',
-                        '腐', '虽', '味',
-                        '移', '泊', '愁', '旷', '萤', '簇',
-                        '喂', '盈', '寿', '合', '茄', '跪', '猛', '庙', '蹲',
-                        '镇', '须', '揉',
-                        '挤', '之', '嫩', '莲', '胀', '姿', '仿', '裳', '翩',
-                        '随', '止',
-                        '依', '否', '窃', '私', '汪', '普', '类', '免', '途',
-                        '镜', '煤', '属', '异',
-                        '药', '诊', '职', '扶', '除', '疑', '效', '缺', '况',
-                        '编', '材', '尝', '传',
-                        '庆', '扬', '叠', '涌', '股', '螺', '旋', '桨', '掠',
-                        '励', '顾', '融', '腾',
-                        '盗', '铛', '偷', '碰', '株', '待', '窜', '撞', '桩',
-                        '捡', '滋', '锄',
-                        '箭', '猎', '雁', '弦', '悲', '惨', '愈', '痛', '拼',
-                        '命',
-                        # '共个字）',
-                    ],
-    ], [
+            '播', '担', '被', '锣', '眨', '咬', '钩', '铜', '微', '转',
+            '卫', '丹', '艺', '旗', '擦', '斜', '男', '显',
+            '澈', '卷', '波', '纹', '丢', '幻', '觉', '消', '表', '演', '扔',
+            '盼',
+            '慌', '针', '辨', '忠', '稠', '稀',
+            '曹', '操', '秤', '砍', '割', '线', '量',
+            '求', '剑', '宝', '催', '靠',
+            '狼', '溪', '脏', '怜', '辩', '扑',
+            '卧', '钻', '剩', '欺', '啄', '讨', '厌', '离',
+        ],
+    ],
+    # 3.1
+    [
         [
+            '匆', '蔼', '尊', '戴', '累', '凑', '补', '输', '液', '扰',
+            '玻', '璃', '吊', '瓶', '默',
+            '汉', '硬', '朗', '县', '济', '毕', '竟', '灵', '便', '及',
+            '盐', '换', '净', '眯',
+            '散', '脯', '蹦', '惹', '仰', '渣', '定', '或', '但', '肯',
 
-            # '字表',
-            # '七册',
-            # '图学文',
+        ], [
+            '诗', '娇', '恰', '菊', '舍', '陶', '偏', '此', '尽',
+            '陡', '级', '铁', '链', '乎', '颤', '奋', '攀', '并', '鲫',
+            '念', '辫', '勇', '决',
+            '欣', '赏', '封', '乳', '浓', '射', '献', '酸', '脆', '参',
+            '刮', '肥', '鼠', '库',
+            '盖', '造', '犁', '断', '减', '扩', '栋', '具', '冒', '柴',
+            '黎', '洪', '何', '括',
+            '焦', '筋', '疲', '喘', '枯', '亡', '牢', '圈', '破', '叼',
+            '劝', '修', '堵', '悔', '受',
+            '招', '副', '善', '性', '特', '骗', '狡', '猾', '使', '劲',
+            '扫', '凶', '恶', '狠', '拾',
+            '摄', '格', '媚', '桌', '志', '贴', '鞠', '躬', '按', '侧',
+            '胶', '辆', '秘', '杂', '社',
+            '财', '富', '厂', '牌', '式', '赠', '拥', '与', '德', '题',
+            '票', '存', '号', '忆',
+            '鹿', '返', '复', '君', '逢', '芙', '蓉', '暮', '贫', '吠',
+            '防', '哨', '峡', '甲', '威', '武', '插', '滩', '壳', '粪',
+            '料', '守', '设', '必', '将',
+            '顿', '庭', '零', '绩', '麦', '奖', '卡', '推', '羞', '通',
+            '愤', '遇', '任', '研', '惯',
+            '基', '础', '差', '末', '考', '试', '均', '厕', '努', '授',
+            '旧', '项', '需', '技', '震',
+            '乘', '轮', '司', '叹', '铃', '裙', '齐', '聪', '佩', '据',
+            '示', '感', '乖', '赞', '致',
+            '棒', '敌', '激', '烈', '陆', '续', '淹', '仍', '吼', '险',
+            '势', '继', '迅', '速', '秒',
+        ],
+    ],
+    # 3.2
+    [
+        [
+            '筝', '育', '鹰', '端', '稳', '嚷', '橘', '墨', '斑',
+            '闹', '宇', '宙', '荡', '衬',
+            '赛', '拨', '警', '惕', '膝', '豪', '套', '倾', '探',
+            '扎', '索', '搂', '贯', '局',
+        ],
+        [
+            '昼', '耘', '未', '耕', '织', '桑', '蓬', '稚', '纶',
+            '莓', '苔',
+            '嘱', '排', '而', '确', '幅', '却', '哈', '审', '肃',
+            '晌', '悦', '悉', '诲',
+            '例', '芝', '卵', '匀', '寸', '呆', '增', '隔', '壁',
+            '搬', '烛', '慈', '肩', '捧',
+            '匠', '伟', '砌', '跨', '创', '既', '击', '毁', '坚',
+            '固', '且', '案', '智', '慧',
+            '阶', '厅', '礼', '席', '灿', '烂', '党', '描', '敞',
+            '椅', '议', '内', '宾',
+            '秆', '绣', '腹', '赤', '衫', '疾', '泛', '泡', '脱',
+            '锐', '晃', '饲', '希',
+            '狭', '桂', '刺', '软', '触', '滑', '唇', '汁', '津',
+            '腐', '虽', '味',
+            '移', '泊', '愁', '旷', '萤', '簇',
+            '喂', '盈', '寿', '合', '茄', '跪', '猛', '庙', '蹲',
+            '镇', '须', '揉',
+            '挤', '之', '嫩', '莲', '胀', '姿', '仿', '裳', '翩',
+            '随', '止',
+            '依', '否', '窃', '私', '汪', '普', '类', '免', '途',
+            '镜', '煤', '属', '异',
+            '药', '诊', '职', '扶', '除', '疑', '效', '缺', '况',
+            '编', '材', '尝', '传',
+            '庆', '扬', '叠', '涌', '股', '螺', '旋', '桨', '掠',
+            '励', '顾', '融', '腾',
+            '盗', '铛', '偷', '碰', '株', '待', '窜', '撞', '桩',
+            '捡', '滋', '锄',
+            '箭', '猎', '雁', '弦', '悲', '惨', '愈', '痛', '拼',
+            '命',
+            # '共个字）',
+        ],
+    ],
+    # 4.1
+    [
+        [
             '联', '雕', '厘', '甚', '鼻', '藏', '概', '淘', '楚', '侵', '衅', '驻',
             '抗',
             '绍', '馆', '戒', '段', '务', '奔', '厉', '弛',
-            # '文',
-        ], [
+        ],
+        [
             '哀', '持', '慰', '谜', '梭', '狂', '赢', '益', '若',
             '凳', '锅', '刷', '替', '抄', '印', '嗓', '捆', '俯', '投', '轰', '隆',
             '爆', '叨',
@@ -389,17 +410,16 @@ cn_ps_c = [
             '堡', '瘦', '纠', '缠', '掏', '乞', '轧', '躺', '饥', '质',
             # '共个字）',
         ]
-    ], [
+    ],
+    # 4.2
+    [
         [
-            # '字表',
-            # '八册',
-            # '图学文',
 
             '趵', '纯', '乏', '藻', '扁',
             '崇', '峻', '蜿', '蜒', '砖', '屯', '垒', '峭', '凝', '魄',
-            # '文：',
 
-        ], [
+        ],
+        [
             '惠', '莺', '郭', '酒',
             '哺', '络', '绎', '桶', '吱', '旬', '拐', '缸', '酬', '俺', '歉', '仅',
             '冶',
@@ -421,10 +441,10 @@ cn_ps_c = [
             '购', '屏', '访', '辅', '邮', '贺', '羡', '宜', '恋', '妙',
             # '共个字）',
         ],
-    ], [
+    ],
+    # 5.1
+    [
         [
-            # '字表',
-            # '九册',
             '刹', '镶',
             '泻', '镀', '润', '杰', '截', '溢', '则', '燃',
 
@@ -447,7 +467,9 @@ cn_ps_c = [
             '托', '批', '糟', '蹋', '尔', '肆', '痰', '核', '呻', '究', '律',
             # '共个字)',
         ],
-    ], [
+    ],
+    # 5.2
+    [
         [
             # '字表',
             # '十册',
@@ -475,12 +497,10 @@ cn_ps_c = [
             '樱',
             # '共个字)',
         ],
-    ], [
+    ],
+    # 6.1
+    [
         [
-
-
-            # '字表',
-            # '十一册',
             '澜', '瑕', '翡', '峦', '障', '筏', '绵',
             '酿', '厦', '伐', '综',
             '锤', '焚',
@@ -499,11 +519,10 @@ cn_ps_c = [
             '俱', '矣', '曰',
             '盂', '沧', '汤',
         ],
-    ], [
+    ],
+    # 6.2
+    [
         [
-            # '共个字)',
-            # '字表',
-            # '十二册',
             '阀', '娱', '僻', '怖', '宪', '胖', '刑', '押', '舅', '绞',
             '彻', '迁', '鸿', '旺', '标', '炊', '葬',
             '权', '溅', '嘹', '魅', '萍', '敏', '滨', '拆', '申',
@@ -517,7 +536,6 @@ cn_ps_c = [
             '搁', '帐', '怨', '掀', '寡', '揍', '魁', '霉', '勺', '熬',
             '鼎', '铸', '铭', '湛', '昌', '熔', '构',
             '寓', '予', '盾', '誉', '吾', '履', '遂',
-            # '共个字)',
         ]
     ]
 ]
